# ps-minifier
A very basic minifier for PowerShell scripts.

Currently, a semicolon (`;`) is required at the end of each line in the script it is given.

NOTE: This minifier is currently not very complex, and (while it works with programs I have tested it on) may not output functioning code for all programs it is given.